@@ -19,7 +19,7 @@ async def init(ctx: Context, force_ca: bool, trust: bool, nginx: bool):
     else:
         ctx.console.print('already exists')
 
-    ctx.console.print(f'located in {await ctx.ca.path.resolve()} with name {ctx.ca.name}')
+    ctx.console.print(f'located in {await ctx.ca.path.absolute()} with name {ctx.ca.name}')
 
     if trust:
         async for db in ctx.keychain.databases():
@@ -27,7 +27,7 @@ async def init(ctx: Context, force_ca: bool, trust: bool, nginx: bool):
             await ctx.keychain.trust_ca(ctx.cmd, ctx.ca, database=db)
 
     if nginx:
-        out_path = await (ctx.data_path/'Nginx'/'ssl'/f'{ctx.ca.name}.conf').resolve()
+        out_path = await (ctx.data_path/'Nginx'/'ssl'/f'{ctx.ca.name}.conf').absolute()
         await out_path.parent.mkdir(parents=True, exist_ok=True)
         await ctx.app.generate_universal_nginx_config(ctx.ca, out_path)
         ctx.console.print(f'nginx config generated to {out_path}')
